@@ -6,7 +6,7 @@ package HTML::AsSubs;
 use warnings;
 use strict;
 
-our $VERSION = '5.909'; # TRIAL VERSION from OurPkgVersion
+our $VERSION = '5.910'; # TRIAL VERSION from OurPkgVersion
 
 require HTML::Element;
 require Exporter;
@@ -73,8 +73,8 @@ HTML::AsSubs - functions that construct a HTML syntax tree
 =head1 VERSION
 
 B<This is a development release for testing purposes only.>
-This document describes version 5.909 of
-HTML::AsSubs, released May 24, 2014
+This document describes version 5.910 of
+HTML::AsSubs, released April 26, 2017
 as part of L<HTML-Tree|HTML::Tree>.
 
 =head1 SYNOPSIS
@@ -186,7 +186,7 @@ Former maintainers:
 =back
 
 You can follow or contribute to HTML-Tree's development at
-L<< https://github.com/madsen/HTML-Tree >>.
+L<< https://github.com/kentfredric/HTML-Tree >>.
 
 =head1 COPYRIGHT AND LICENSE
 
