@@ -8,7 +8,7 @@ package HTML::Element::traverse;
 use warnings;
 use strict;
 
-our $VERSION = '5.909'; # TRIAL VERSION from OurPkgVersion
+our $VERSION = '5.910'; # TRIAL VERSION from OurPkgVersion
 
 use HTML::Element ();
 1;
@@ -24,8 +24,8 @@ HTML::Element::traverse - discussion of HTML::Element's traverse method
 =head1 VERSION
 
 B<This is a development release for testing purposes only.>
-This document describes version 5.909 of
-HTML::Element::traverse, released May 24, 2014
+This document describes version 5.910 of
+HTML::Element::traverse, released April 26, 2017
 as part of L<HTML-Tree|HTML::Tree>.
 
 =head1 SYNOPSIS
@@ -366,7 +366,7 @@ Former maintainers:
 =back
 
 You can follow or contribute to HTML-Tree's development at
-L<< https://github.com/madsen/HTML-Tree >>.
+L<< https://github.com/kentfredric/HTML-Tree >>.
 
 =head1 COPYRIGHT
 
